// Copyright 2026 The Sigstore Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v4.24.4
// source: predicate.proto

package predicate

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GitCommit struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Source        *Commit                `protobuf:"bytes,1,opt,name=source,proto3" json:"source,omitempty"`
	Signature     string                 `protobuf:"bytes,2,opt,name=signature,proto3" json:"signature,omitempty"`
	SignerInfo    []*SignerInfo          `protobuf:"bytes,3,rep,name=signer_info,proto3" json:"signer_info,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GitCommit) Reset() {
	*x = GitCommit{}
	mi := &file_predicate_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GitCommit) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GitCommit) ProtoMessage() {}

func (x *GitCommit) ProtoReflect() protoreflect.Message {
	mi := &file_predicate_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GitCommit.ProtoReflect.Descriptor instead.
func (*GitCommit) Descriptor() ([]byte, []int) {
	return file_predicate_proto_rawDescGZIP(), []int{0}
}

func (x *GitCommit) GetSource() *Commit {
	if x != nil {
		return x.Source
	}
	return nil
}

func (x *GitCommit) GetSignature() string {
	if x != nil {
		return x.Signature
	}
	return ""
}

func (x *GitCommit) GetSignerInfo() []*SignerInfo {
	if x != nil {
		return x.SignerInfo
	}
	return nil
}

type GitTag struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Source        *Tag                   `protobuf:"bytes,4,opt,name=source,proto3" json:"source,omitempty"`
	Signature     string                 `protobuf:"bytes,2,opt,name=signature,proto3" json:"signature,omitempty"`
	SignerInfo    []*SignerInfo          `protobuf:"bytes,3,rep,name=signer_info,proto3" json:"signer_info,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GitTag) Reset() {
	*x = GitTag{}
	mi := &file_predicate_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GitTag) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GitTag) ProtoMessage() {}

func (x *GitTag) ProtoReflect() protoreflect.Message {
	mi := &file_predicate_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GitTag.ProtoReflect.Descriptor instead.
func (*GitTag) Descriptor() ([]byte, []int) {
	return file_predicate_proto_rawDescGZIP(), []int{1}
}

func (x *GitTag) GetSource() *Tag {
	if x != nil {
		return x.Source
	}
	return nil
}

func (x *GitTag) GetSignature() string {
	if x != nil {
		return x.Signature
	}
	return ""
}

func (x *GitTag) GetSignerInfo() []*SignerInfo {
	if x != nil {
		return x.SignerInfo
	}
	return nil
}

type Tag struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Object        string                 `protobuf:"bytes,1,opt,name=object,proto3" json:"object,omitempty"`
	ObjectType    string                 `protobuf:"bytes,2,opt,name=object_type,proto3" json:"object_type,omitempty"` // object type (eg 'commit')
	Tag           string                 `protobuf:"bytes,3,opt,name=tag,proto3" json:"tag,omitempty"`
	Tagger        *Author                `protobuf:"bytes,4,opt,name=tagger,proto3" json:"tagger,omitempty"`
	Message       string                 `protobuf:"bytes,5,opt,name=message,proto3" json:"message,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Tag) Reset() {
	*x = Tag{}
	mi := &file_predicate_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Tag) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Tag) ProtoMessage() {}

func (x *Tag) ProtoReflect() protoreflect.Message {
	mi := &file_predicate_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Tag.ProtoReflect.Descriptor instead.
func (*Tag) Descriptor() ([]byte, []int) {
	return file_predicate_proto_rawDescGZIP(), []int{2}
}

func (x *Tag) GetObject() string {
	if x != nil {
		return x.Object
	}
	return ""
}

func (x *Tag) GetObjectType() string {
	if x != nil {
		return x.ObjectType
	}
	return ""
}

func (x *Tag) GetTag() string {
	if x != nil {
		return x.Tag
	}
	return ""
}

func (x *Tag) GetTagger() *Author {
	if x != nil {
		return x.Tagger
	}
	return nil
}

func (x *Tag) GetMessage() string {
	if x != nil {
		return x.Message
	}
	return ""
}

type Commit struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Tree          string                 `protobuf:"bytes,1,opt,name=tree,proto3" json:"tree,omitempty"`
	Parents       []string               `protobuf:"bytes,2,rep,name=parents,proto3" json:"parents,omitempty"`
	Author        *Author                `protobuf:"bytes,3,opt,name=author,proto3" json:"author,omitempty"`
	Committer     *Author                `protobuf:"bytes,4,opt,name=committer,proto3" json:"committer,omitempty"`
	Message       string                 `protobuf:"bytes,5,opt,name=message,proto3" json:"message,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Commit) Reset() {
	*x = Commit{}
	mi := &file_predicate_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Commit) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Commit) ProtoMessage() {}

func (x *Commit) ProtoReflect() protoreflect.Message {
	mi := &file_predicate_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Commit.ProtoReflect.Descriptor instead.
func (*Commit) Descriptor() ([]byte, []int) {
	return file_predicate_proto_rawDescGZIP(), []int{3}
}

func (x *Commit) GetTree() string {
	if x != nil {
		return x.Tree
	}
	return ""
}

func (x *Commit) GetParents() []string {
	if x != nil {
		return x.Parents
	}
	return nil
}

func (x *Commit) GetAuthor() *Author {
	if x != nil {
		return x.Author
	}
	return nil
}

func (x *Commit) GetCommitter() *Author {
	if x != nil {
		return x.Committer
	}
	return nil
}

func (x *Commit) GetMessage() string {
	if x != nil {
		return x.Message
	}
	return ""
}

type Author struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Email         string                 `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
	Date          *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=date,proto3" json:"date,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Author) Reset() {
	*x = Author{}
	mi := &file_predicate_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Author) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Author) ProtoMessage() {}

func (x *Author) ProtoReflect() protoreflect.Message {
	mi := &file_predicate_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Author.ProtoReflect.Descriptor instead.
func (*Author) Descriptor() ([]byte, []int) {
	return file_predicate_proto_rawDescGZIP(), []int{4}
}

func (x *Author) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *Author) GetEmail() string {
	if x != nil {
		return x.Email
	}
	return ""
}

func (x *Author) GetDate() *timestamppb.Timestamp {
	if x != nil {
		return x.Date
	}
	return nil
}

type SignerInfo struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Attributes    string                 `protobuf:"bytes,1,opt,name=attributes,proto3" json:"attributes,omitempty"`
	Certificate   string                 `protobuf:"bytes,2,opt,name=certificate,proto3" json:"certificate,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SignerInfo) Reset() {
	*x = SignerInfo{}
	mi := &file_predicate_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SignerInfo) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SignerInfo) ProtoMessage() {}

func (x *SignerInfo) ProtoReflect() protoreflect.Message {
	mi := &file_predicate_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SignerInfo.ProtoReflect.Descriptor instead.
func (*SignerInfo) Descriptor() ([]byte, []int) {
	return file_predicate_proto_rawDescGZIP(), []int{5}
}

func (x *SignerInfo) GetAttributes() string {
	if x != nil {
		return x.Attributes
	}
	return ""
}

func (x *SignerInfo) GetCertificate() string {
	if x != nil {
		return x.Certificate
	}
	return ""
}

var File_predicate_proto protoreflect.FileDescriptor

const file_predicate_proto_rawDesc = "" +
	"\n" +
	"\x0fpredicate.proto\x12\x1esigstore.gitsign.predicate.v01\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x01\n" +
	"\tGitCommit\x12>\n" +
	"\x06source\x18\x01 \x01(\v2&.sigstore.gitsign.predicate.v01.CommitR\x06source\x12\x1c\n" +
	"\tsignature\x18\x02 \x01(\tR\tsignature\x12L\n" +
	"\vsigner_info\x18\x03 \x03(\v2*.sigstore.gitsign.predicate.v01.SignerInfoR\vsigner_info\"\xb1\x01\n" +
	"\x06GitTag\x12;\n" +
	"\x06source\x18\x04 \x01(\v2#.sigstore.gitsign.predicate.v01.TagR\x06source\x12\x1c\n" +
	"\tsignature\x18\x02 \x01(\tR\tsignature\x12L\n" +
	"\vsigner_info\x18\x03 \x03(\v2*.sigstore.gitsign.predicate.v01.SignerInfoR\vsigner_info\"\xab\x01\n" +
	"\x03Tag\x12\x16\n" +
	"\x06object\x18\x01 \x01(\tR\x06object\x12 \n" +
	"\vobject_type\x18\x02 \x01(\tR\vobject_type\x12\x10\n" +
	"\x03tag\x18\x03 \x01(\tR\x03tag\x12>\n" +
	"\x06tagger\x18\x04 \x01(\v2&.sigstore.gitsign.predicate.v01.AuthorR\x06tagger\x12\x18\n" +
	"\amessage\x18\x05 \x01(\tR\amessage\"\xd6\x01\n" +
	"\x06Commit\x12\x12\n" +
	"\x04tree\x18\x01 \x01(\tR\x04tree\x12\x18\n" +
	"\aparents\x18\x02 \x03(\tR\aparents\x12>\n" +
	"\x06author\x18\x03 \x01(\v2&.sigstore.gitsign.predicate.v01.AuthorR\x06author\x12D\n" +
	"\tcommitter\x18\x04 \x01(\v2&.sigstore.gitsign.predicate.v01.AuthorR\tcommitter\x12\x18\n" +
	"\amessage\x18\x05 \x01(\tR\amessage\"b\n" +
	"\x06Author\x12\x12\n" +
	"\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n" +
	"\x05email\x18\x02 \x01(\tR\x05email\x12.\n" +
	"\x04date\x18\x03 \x01(\v2\x1a.google.protobuf.TimestampR\x04date\"N\n" +
	"\n" +
	"SignerInfo\x12\x1e\n" +
	"\n" +
	"attributes\x18\x01 \x01(\tR\n" +
	"attributes\x12 \n" +
	"\vcertificate\x18\x02 \x01(\tR\vcertificateB+Z)github.com/sigstore/gitsign/pkg/predicateb\x06proto3"

var (
	file_predicate_proto_rawDescOnce sync.Once
	file_predicate_proto_rawDescData []byte
)

func file_predicate_proto_rawDescGZIP() []byte {
	file_predicate_proto_rawDescOnce.Do(func() {
		file_predicate_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_predicate_proto_rawDesc), len(file_predicate_proto_rawDesc)))
	})
	return file_predicate_proto_rawDescData
}

var file_predicate_proto_msgTypes = make([]protoimpl.MessageInfo, 6)
var file_predicate_proto_goTypes = []any{
	(*GitCommit)(nil),             // 0: sigstore.gitsign.predicate.v01.GitCommit
	(*GitTag)(nil),                // 1: sigstore.gitsign.predicate.v01.GitTag
	(*Tag)(nil),                   // 2: sigstore.gitsign.predicate.v01.Tag
	(*Commit)(nil),                // 3: sigstore.gitsign.predicate.v01.Commit
	(*Author)(nil),                // 4: sigstore.gitsign.predicate.v01.Author
	(*SignerInfo)(nil),            // 5: sigstore.gitsign.predicate.v01.SignerInfo
	(*timestamppb.Timestamp)(nil), // 6: google.protobuf.Timestamp
}
var file_predicate_proto_depIdxs = []int32{
	3, // 0: sigstore.gitsign.predicate.v01.GitCommit.source:type_name -> sigstore.gitsign.predicate.v01.Commit
	5, // 1: sigstore.gitsign.predicate.v01.GitCommit.signer_info:type_name -> sigstore.gitsign.predicate.v01.SignerInfo
	2, // 2: sigstore.gitsign.predicate.v01.GitTag.source:type_name -> sigstore.gitsign.predicate.v01.Tag
	5, // 3: sigstore.gitsign.predicate.v01.GitTag.signer_info:type_name -> sigstore.gitsign.predicate.v01.SignerInfo
	4, // 4: sigstore.gitsign.predicate.v01.Tag.tagger:type_name -> sigstore.gitsign.predicate.v01.Author
	4, // 5: sigstore.gitsign.predicate.v01.Commit.author:type_name -> sigstore.gitsign.predicate.v01.Author
	4, // 6: sigstore.gitsign.predicate.v01.Commit.committer:type_name -> sigstore.gitsign.predicate.v01.Author
	6, // 7: sigstore.gitsign.predicate.v01.Author.date:type_name -> google.protobuf.Timestamp
	8, // [8:8] is the sub-list for method output_type
	8, // [8:8] is the sub-list for method input_type
	8, // [8:8] is the sub-list for extension type_name
	8, // [8:8] is the sub-list for extension extendee
	0, // [0:8] is the sub-list for field type_name
}

func init() { file_predicate_proto_init() }
func file_predicate_proto_init() {
	if File_predicate_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_predicate_proto_rawDesc), len(file_predicate_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   6,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_predicate_proto_goTypes,
		DependencyIndexes: file_predicate_proto_depIdxs,
		MessageInfos:      file_predicate_proto_msgTypes,
	}.Build()
	File_predicate_proto = out.File
	file_predicate_proto_goTypes = nil
	file_predicate_proto_depIdxs = nil
}
