#!/usr/bin/env bash

# Copyright 2026 The Sigstore Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set -euo pipefail

REPO_ROOT="$(cd "$(dirname "${BASH_SOURCE[0]}")/.." && pwd)"
cd "${REPO_ROOT}"

echo -n "Generating protobuf Go code..."

# Check if protoc is installed
if ! command -v protoc &> /dev/null; then
    echo
    echo "Error: protoc is not installed."
    exit 1
fi

# Check if protoc-gen-go is installed
if ! command -v protoc-gen-go &> /dev/null; then
    echo
    echo "Error: protoc-gen-go is not installed."
    exit 1
fi

# Generate the Go types from the proto definitions
protoc \
    --go_out=. \
    --go_opt=module=github.com/sigstore/gitsign \
    --proto_path=proto/v01 \
    proto/v01/predicate.proto

echo "  done!"
