//
// Copyright 2022 The Sigstore Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package main

import (
	"fmt"
	"os"

	// Enable OIDC providers
	_ "github.com/sigstore/cosign/v3/pkg/providers/all"
	"github.com/sigstore/gitsign/internal/commands/root"
	"github.com/sigstore/gitsign/internal/config"
)

func main() {
	cfg, err := config.Get()
	if err != nil {
		fmt.Fprintln(os.Stderr, err)
		os.Exit(2)
	}

	rootCmd := root.New(cfg)

	if err := rootCmd.Execute(); err != nil {
		os.Exit(1)
	}
}
